/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-10-01
 * Description : a kipi plugin to batch process images
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_BATCHPROCESSIMAGES_H
#define PLUGIN_BATCHPROCESSIMAGES_H

// Include files for TQt

#include <tqstring.h>

// Include files for KDE

#include <libkipi/plugin.h>

class TDEAction;

namespace KIPIBatchProcessImagesPlugin {
    class BorderImagesDialog;
    class ColorImagesDialog;
    class ConvertImagesDialog;
    class EffectImagesDialog;
    class FilterImagesDialog;
    class RenameImagesDialog;
    class RecompressImagesDialog;
    class ResizeImagesDialog;
}

class Plugin_BatchProcessImages : public KIPI::Plugin
{
TQ_OBJECT
  

public:
  Plugin_BatchProcessImages(TQObject *parent, const char* name, const TQStringList &args);
  virtual ~Plugin_BatchProcessImages();
  virtual KIPI::Category category( TDEAction* action ) const;
  virtual void setup( TQWidget* );

public slots:
  void slotActivate();

private:
  TDEAction                *m_action_borderimages;
  TDEAction                *m_action_colorimages;
  TDEAction                *m_action_convertimages;
  TDEAction                *m_action_effectimages;
  TDEAction                *m_action_filterimages;
  TDEAction                *m_action_renameimages;
  TDEAction                *m_action_recompressimages;
  TDEAction                *m_action_resizeimages;


  KIPIBatchProcessImagesPlugin::BorderImagesDialog     *m_BorderImagesDialog;
  KIPIBatchProcessImagesPlugin::ColorImagesDialog      *m_ColorImagesDialog;
  KIPIBatchProcessImagesPlugin::ConvertImagesDialog    *m_ConvertImagesDialog;
  KIPIBatchProcessImagesPlugin::EffectImagesDialog     *m_EffectImagesDialog;
  KIPIBatchProcessImagesPlugin::FilterImagesDialog     *m_FilterImagesDialog;
  KIPIBatchProcessImagesPlugin::RenameImagesDialog     *m_RenameImagesDialog;
  KIPIBatchProcessImagesPlugin::RecompressImagesDialog *m_RecompressImagesDialog;
  KIPIBatchProcessImagesPlugin::ResizeImagesDialog     *m_ResizeImagesDialog;
};


#endif /* PLUGIN_BATCHPROCESSIMAGES_H */
